==> poetry_aws_lambda_plugin-0.1.0-py3-none-any.whl: poetry_aws_lambda_plugin/utils/config.py <==
from __future__ import annotations

from functools import cached_property, lru_cache
from typing import TYPE_CHECKING

from poetry.core.constraints.version import Version, VersionRange
from poetry_aws_lambda_plugin.utils.enums import LambdaResource, LambdaArchitecture, CompressionType
from poetry_aws_lambda_plugin.utils.exceptions import PoetryAwsLambdaPluginException

if TYPE_CHECKING:
    from pathlib import Path
    from typing import Set, Optional

    from poetry.console.commands.group_command import GroupCommand


class Config:
    def __init__(
            self,
            command: GroupCommand
    ) -> None:
        self._command = command

    @cached_property
    def all_artefacts_path(self) -> Path:
        return self._command.poetry.pyproject_path.parent.joinpath("dist")

    @cached_property
    def lambda_artefacts_path(self) -> Path:
        return self.all_artefacts_path.joinpath("lambda")

    @cached_property
    def dry_run(self) -> bool:
        return self._command.option("dry-run")

    @cached_property
    def activated_groups(self) -> Set[str]:
        return self._command.activated_groups

    @cached_property
    def no_root(self) -> bool:
        return self._command.option("no-root")

    @cached_property
    def only_root(self) -> bool:
        return self._command.option("only-root")

    @cached_property
    def lambda_runtime_python_version(self) -> Version:
        python_constraint = self._command.poetry.package.python_constraint
        python_version = None
        if isinstance(python_constraint, VersionRange):
            if python_constraint.include_min:
                python_version = python_constraint.min

        if (python_version is None) or (python_version.major is None) or (python_version.minor is None):
            raise PoetryAwsLambdaPluginException(
                f"Cannot determine a Lambda Python Runtime "
                f"from package Python constraint {python_constraint}"
            )

        return Version.parse(f"{python_version.major}.{python_version.minor}")

    @cached_property
    def lambda_resource(self) -> LambdaResource:
        resource_option = self._command.option("resource").upper()
        if resource_option not in LambdaResource.__members__:
            raise PoetryAwsLambdaPluginException(
                f"Invalid Lambda Resource ({resource_option}), "
                f"must be one of {', '.join(LambdaResource.__members__)}."
            )
        return LambdaResource[resource_option]

    @cached_property
    def lambda_architecture(self) -> LambdaArchitecture:
        architecture_option = self._command.option("architecture").upper()
        if architecture_option not in LambdaArchitecture.__members__:
            raise PoetryAwsLambdaPluginException(
                f"Invalid Lambda Architecture ({architecture_option}), "
                f"must be one of {', '.join(LambdaArchitecture.__members__)}."
            )
        return LambdaArchitecture[architecture_option]

    @cached_property
    def compression_type(self) -> CompressionType:
        ct_config = (self._command.poetry.pyproject.data
                     .get("aws-lambda", {})
                     .get("compression-type", "deflated")).upper()
        if ct_config not in CompressionType.__members__:
            raise PoetryAwsLambdaPluginException(
                f"Invalid Compression Type ({ct_config}), "
                f"must be one of {', '.join(CompressionType.__members__)}."
            )
        return CompressionType[ct_config]

    @cached_property
    def compression_level(self) -> int:
        ct = self.compression_type
        cl_conf = (self._command.poetry.pyproject.data
                   .get("aws-lambda", {})
                   .get("compression-level", ct.min_compression_level))

        if ct.adjustable:
            if (cl_conf < ct.min_compression_level) or (cl_conf > ct.max_compression_level):
                raise PoetryAwsLambdaPluginException(
                    f"Invalid Compression Level ({cl_conf}), "
                    f"must be between {ct.min_compression_level} and {ct.max_compression_level} "
                    f"for {ct.name}."
                )
        elif cl_conf != ct.min_compression_level:
            raise PoetryAwsLambdaPluginException(
                f"Invalid Compression Level ({cl_conf}), "
                f"must be {ct.min_compression_level} for {ct.name} (not adjustable)."
            )

        return cl_conf

    @cached_property
    def slimmers(self) -> Optional[Set[str]]:
        return (self._command.poetry.pyproject.data
                .get("aws-lambda", {})
                .get("slimmers", None))

    @lru_cache(maxsize=None)
    def slimmer_enabled(self, slimmer: str) -> bool:
        return (self.slimmers is None) or (slimmer in self.slimmers)

==> poetry_aws_lambda_plugin-0.1.1-py3-none-any.whl: poetry_aws_lambda_plugin/utils/config.py <==
from __future__ import annotations

from functools import cached_property, lru_cache
from typing import TYPE_CHECKING

from poetry.core.constraints.version import Version, VersionRange
from poetry_aws_lambda_plugin.utils.enums import LambdaResource, LambdaArchitecture, CompressionType
from poetry_aws_lambda_plugin.utils.exceptions import PoetryAwsLambdaPluginException

if TYPE_CHECKING:
    from pathlib import Path
    from typing import Set, Optional

    from poetry.console.commands.group_command import GroupCommand


class Config:
    def __init__(
            self,
            command: GroupCommand
    ) -> None:
        self._command = command

    @cached_property
    def all_artefacts_path(self) -> Path:
        return self._command.poetry.pyproject_path.parent.joinpath("dist")

    @cached_property
    def lambda_artefacts_path(self) -> Path:
        return self.all_artefacts_path.joinpath("lambda")

    @cached_property
    def dry_run(self) -> bool:
        return self._command.option("dry-run")

    @cached_property
    def activated_groups(self) -> Set[str]:
        return self._command.activated_groups

    @cached_property
    def no_root(self) -> bool:
        return self._command.option("no-root")

    @cached_property
    def only_root(self) -> bool:
        return self._command.option("only-root")

    @cached_property
    def lambda_runtime_python_version(self) -> Version:
        python_constraint = self._command.poetry.package.python_constraint
        python_version = None
        if isinstance(python_constraint, VersionRange):
            if python_constraint.include_min:
                python_version = python_constraint.min

        if (python_version is None) or (python_version.major is None) or (python_version.minor is None):
            raise PoetryAwsLambdaPluginException(
                f"Cannot determine a Lambda Python Runtime "
                f"from package Python constraint {python_constraint}"
            )

        return Version.parse(f"{python_version.major}.{python_version.minor}")

    @cached_property
    def lambda_resource(self) -> LambdaResource:
        resource_option = self._command.option("resource").upper()
        if resource_option not in LambdaResource.__members__:
            raise PoetryAwsLambdaPluginException(
                f"Invalid Lambda Resource ({resource_option}), "
                f"must be one of {', '.join(LambdaResource.__members__)}."
            )
        return LambdaResource[resource_option]

    @cached_property
    def lambda_architecture(self) -> LambdaArchitecture:
        architecture_option = self._command.option("architecture").upper()
        if architecture_option not in LambdaArchitecture.__members__:
            raise PoetryAwsLambdaPluginException(
                f"Invalid Lambda Architecture ({architecture_option}), "
                f"must be one of {', '.join(LambdaArchitecture.__members__)}."
            )
        return LambdaArchitecture[architecture_option]

    @cached_property
    def compression_type(self) -> CompressionType:
        ct_config = (self._command.poetry.pyproject.data
                     .get("aws-lambda", {})
                     .get("compression-type", CompressionType.BZIP2.name)).upper()
        if ct_config not in CompressionType.__members__:
            raise PoetryAwsLambdaPluginException(
                f"Invalid Compression Type ({ct_config}), "
                f"must be one of {', '.join(CompressionType.__members__)}."
            )
        return CompressionType[ct_config]

    @cached_property
    def compression_level(self) -> int:
        ct = self.compression_type
        cl_conf = (self._command.poetry.pyproject.data
                   .get("aws-lambda", {})
                   .get("compression-level", ct.min_compression_level))

        if ct.adjustable:
            if (cl_conf < ct.min_compression_level) or (cl_conf > ct.max_compression_level):
                raise PoetryAwsLambdaPluginException(
                    f"Invalid Compression Level ({cl_conf}), "
                    f"must be between {ct.min_compression_level} and {ct.max_compression_level} "
                    f"for {ct.name}."
                )
        elif cl_conf != ct.min_compression_level:
            raise PoetryAwsLambdaPluginException(
                f"Invalid Compression Level ({cl_conf}), "
                f"must be {ct.min_compression_level} for {ct.name} (not adjustable)."
            )

        return cl_conf

    @cached_property
    def slimmers(self) -> Optional[Set[str]]:
        return (self._command.poetry.pyproject.data
                .get("aws-lambda", {})
                .get("slimmers", None))

    @lru_cache(maxsize=None)
    def slimmer_enabled(self, slimmer: str) -> bool:
        return (self.slimmers is None) or (slimmer in self.slimmers)
